@@ -1,8 +1,13 @@
+from async_lru import alru_cache
+
 from ..core import APIManager, method_rate_limit
+from ..core.exceptions import APINotFoundError
 from ..schemas.fbs import PostingFBSUnfulfilledListRequest, PostingFBSUnfulfilledListResponse, PostingFBSListResponse, \
     PostingFBSListRequest, PostingFBSGetRequest, PostingFBSGetResponse, PostingFBSGetByBarcodeResponse, \
     PostingFBSGetByBarcodeRequest, PostingFBSMultiBoxQtySetResponse, PostingFBSMultiBoxQtySetRequest, \
-    PostingFBSProductChangeRequest, PostingFBSProductChangeResponse
+    PostingFBSProductChangeRequest, PostingFBSProductChangeResponse, PostingFBSProductCountryListResponse, \
+    PostingFBSProductCountryListRequest, PostingFBSProductCountrySetRequest, PostingFBSProductCountrySetResponse, \
+    PostingFBSRestrictionsResponse, PostingFBSRestrictionsRequest
 
 
 class SellerFBSAPI(APIManager):
@@ -339,4 +344,134 @@ class SellerFBSAPI(APIManager):
             endpoint="posting/fbs/product/change",
             json=request.model_dump(by_alias=True)
         )
-        return PostingFBSProductChangeResponse(**response)
\ No newline at end of file
+        return PostingFBSProductChangeResponse(**response)
+
+    @alru_cache(ttl=86400)
+    async def posting_fbs_product_country_list(
+            self: "SellerFBSAPI",
+            request: PostingFBSProductCountryListRequest = PostingFBSProductCountryListRequest.model_construct()
+    ) -> PostingFBSProductCountryListResponse:
+        """Метод для получения списка доступных стран-изготовителей и их ISO кодов.
+
+        Notes:
+            • Метод возвращает полный список стран-изготовителей, доступных для указания в карточках товаров.
+            • Для фильтрации результатов можно использовать параметр `name_search` - поисковая строка по названию страны.
+            • Если параметр `name_search` не указан или пустой, возвращается полный список всех доступных стран.
+            • Поиск осуществляется по частичному совпадению с названием страны на русском языке.
+            • Регистр букв в поисковой строке не имеет значения.
+            • ISO код страны возвращается в формате двухбуквенного кода (Alpha-2) согласно стандарту ISO 3166-1.
+
+        References:
+            https://docs.ozon.ru/api/seller/?__rr=1#operation/PostingAPI_ListCountryProductFbsPostingV2
+
+        Args:
+            request: Запрос на получение списка стран-изготовителей по схеме `PostingFBSProductCountryListRequest`
+
+        Returns:
+            Список доступных стран-изготовителей с их ISO кодами по схеме `PostingFBSProductCountryListResponse`
+
+        Examples:
+            Базовое применение (получение полного списка стран):
+                async with SellerAPI(client_id, api_key) as api:
+                    result = await api.posting_fbs_product_country_list(
+                        PostingFBSProductCountryListRequest()
+                    )
+
+            Пример с фильтрацией по названию страны (частичное совпадение):
+                async with SellerAPI(client_id, api_key) as api:
+                    result = await api.posting_fbs_product_country_list(
+                        PostingFBSProductCountryListRequest(
+                            name_search="тУрЦ"
+                        )
+                    )
+        """
+        try:
+            response = await self._request(
+                method="post",
+                api_version="v2",
+                endpoint="posting/fbs/product/country/list",
+                json=request.model_dump()
+            )
+        except APINotFoundError:
+            return PostingFBSProductCountryListResponse.model_construct()
+        return PostingFBSProductCountryListResponse(**response)
+
+    async def posting_fbs_product_country_set(
+            self: "SellerFBSAPI",
+            request: PostingFBSProductCountrySetRequest
+    ) -> PostingFBSProductCountrySetResponse:
+        """Метод для добавления информации о стране-изготовителе товара в отправлении FBS.
+
+        Notes:
+            • Метод используется для добавления атрибута «Страна-изготовитель» к товару в отправлении, если он не был указан ранее.
+            • Страна-изготовитель указывается в формате двухбуквенного кода стандарта ISO 3166-1 (Alpha-2).
+            • Список доступных стран-изготовителей и их ISO кодов можно получить с помощью метода posting_fbs_product_country_list().
+            • После успешного выполнения метода система возвращает признак необходимости передачи номера ГТД (грузовой таможенной декларации).
+            • Если is_gtd_needed = true, необходимо передать номер ГТД для указанного продукта и отправления.
+            • Метод может быть применен только к отправлениям, где страна-изготовитель еще не указана.
+
+        References:
+            https://docs.ozon.ru/api/seller/?#operation/PostingAPI_SetCountryProductFbsPostingV2
+
+        Args:
+            request: Запрос на добавление информации о стране-изготовителе товара по схеме `PostingFBSProductCountrySetRequest`
+
+        Returns:
+            Результат выполнения операции с информацией о необходимости ГТД по схеме `PostingFBSProductCountrySetResponse`
+
+        Examples:
+            async with SellerAPI(client_id, api_key) as api:
+                result = await api.posting_fbs_product_country_set(
+                    PostingFBSProductCountrySetRequest(
+                        posting_number="57195475-0050-3",
+                        product_id=180550365,
+                        country_iso_code="NO"
+                    )
+                )
+        """
+        response = await self._request(
+            method="post",
+            api_version="v2",
+            endpoint="posting/fbs/product/country/set",
+            json=request.model_dump()
+        )
+        return PostingFBSProductCountrySetResponse(**response)
+
+    async def posting_fbs_restrictions(
+            self: "SellerFBSAPI",
+            request: PostingFBSRestrictionsRequest
+    ) -> PostingFBSRestrictionsResponse:
+        """Метод для получения габаритных, весовых и прочих ограничений пункта приёма по номеру отправления.
+
+        Notes:
+            • Метод применим только для работы по схеме FBS.
+            • Возвращает ограничения пункта приёма, связанные с указанным отправлением.
+            • Ограничения включают габаритные (ширина, высота, длина), весовые (мин./макс. вес) и стоимостные (мин./макс. цена) параметры.
+            • Вес указывается в граммах, габариты — в сантиметрах, стоимость — в рублях.
+            • Если для какого-то параметра ограничение не установлено, значение будет None.
+            • Метод помогает определить, соответствует ли отправление требованиям пункта приёма перед передачей.
+
+        References:
+            https://docs.ozon.ru/api/seller/?#operation/PostingAPI_GetRestrictions
+
+        Args:
+            request: Запрос на получение ограничений пункта приёма по номеру отправления по схеме `PostingFBSRestrictionsRequest`
+
+        Returns:
+            Ограничения пункта приёма для указанного отправления по схеме `PostingFBSRestrictionsResponse`
+
+        Examples:
+            async with SellerAPI(client_id, api_key) as api:
+                result = await api.posting_fbs_restrictions(
+                    PostingFBSRestrictionsRequest(
+                        posting_number="76673629-0020-1"
+                    )
+                )
+        """
+        response = await self._request(
+            method="post",
+            api_version="v1",
+            endpoint="posting/fbs/restrictions",
+            json=request.model_dump()
+        )
+        return PostingFBSRestrictionsResponse(**response["result"])
\ No newline at end of file
