@@ -33,6 +33,7 @@ __all__ = [
     "ProductInfoAttributesFilter",
     "ProductInfoAttributesPdfFile",
     "ProductInfoAttributesModelInfo",
+    "ProductInfoLimitResponse",
     "ProductInfoListRequest",
     "ProductInfoListResponse",
     "ProductInfoListItem",
@@ -57,6 +58,8 @@ __all__ = [
     "ProductListResponseItem",
     "ProductListResponseResult",
     "ProductListQuants",
+    "ProductPicturesImportRequest",
+    "ProductPicturesImportResponse",
     "ProductPicturesInfoRequest",
     "ProductPicturesInfoResponse",
     "ProductPicturesInfoItem",
@@ -104,6 +107,7 @@ from .v1__product_info_subscription import (
     ProductInfoSubscriptionRequest,
     ProductInfoSubscriptionItem,
 )
+from .v1__product_pictures_import import ProductPicturesImportResponse, ProductPicturesImportRequest
 from .v1__product_rating_by_sku import (
     ProductRatingBySkuResponse, 
     ProductRatingBySkuRequest,
@@ -170,6 +174,7 @@ from .v3__product_list import (
     ProductListResponseResult,
     ProductListQuants,
 )
+from .v4__product_info_limit import ProductInfoLimitResponse
 from .v4__product_info_attributes import (
     ProductInfoAttributesResponse, 
     ProductInfoAttributesRequest,
