@@ -6,7 +6,8 @@ from pydantic import BaseModel, Field, model_validator
 
 from .base import BaseProductInfoListRequest
 from ...common.enumerations.localization import CurrencyCode
-from ...common.enumerations.products import ErrorLevel, ColorIndex, ShipmentType, VAT
+from ...common.enumerations.products import ErrorLevel, ShipmentType
+from ...common.enumerations.prices import VAT, ColorIndexWithPrefix
 
 
 class ProductInfoListRequest(BaseProductInfoListRequest):
@@ -18,9 +19,9 @@ class ProductInfoListRequest(BaseProductInfoListRequest):
         sku: Идентификаторы товаров в системе Ozon (опционально)
     """
     @model_validator(mode='after')
-    def validate_total_items_count(cls, values):
+    def validate_total_items_count(self):
         """Проверяет, что сумма элементов по всем параметрам не превышает 1000."""
-        fields_to_check = [values.offer_id, values.product_id, values.sku]
+        fields_to_check = [self.offer_id, self.product_id, self.sku]
 
         total_count = sum(len(field) for field in fields_to_check if field is not None)
 
@@ -29,7 +30,7 @@ class ProductInfoListRequest(BaseProductInfoListRequest):
                 f"Общее количество идентификаторов ({total_count}) в запросе превышает максимально допустимое значение 1000."
             )
 
-        return values
+        return self
 
 
 class ProductInfoListErrorTextsParams(BaseModel):
@@ -168,7 +169,7 @@ class ProductInfoListPriceIndexes(BaseModel):
         ozon_index_data: Цена товара у конкурентов на Ozon
         self_marketplaces_index_data: Цена товара на других площадках
     """
-    color_index: ColorIndex = Field(
+    color_index: ColorIndexWithPrefix = Field(
         ..., description="Вид индекса цен."
     )
     external_index_data: ProductInfoListPriceIndexData | None = Field(
